@@ -10,14 +10,17 @@ import (
 	"github.com/aquasecurity/fanal/analyzer"
 	"github.com/aquasecurity/fanal/analyzer/config"
 	"github.com/aquasecurity/trivy/pkg/cache"
+	"github.com/aquasecurity/trivy/pkg/commands/operation"
 	"github.com/aquasecurity/trivy/pkg/log"
-	"github.com/aquasecurity/trivy/pkg/report"
+	pkgReport "github.com/aquasecurity/trivy/pkg/report"
 	"github.com/aquasecurity/trivy/pkg/rpc/client"
 	"github.com/aquasecurity/trivy/pkg/scanner"
 	"github.com/aquasecurity/trivy/pkg/types"
 	"github.com/aquasecurity/trivy/pkg/utils"
 )
 
+const defaultPolicyNamespace = "appshield"
+
 // Run runs the scan
 func Run(cliCtx *cli.Context) error {
 	opt, err := NewOption(cliCtx)
@@ -55,25 +58,37 @@ func runWithTimeout(ctx context.Context, opt Option) error {
 		VulnType:            opt.VulnType,
 		SecurityChecks:      opt.SecurityChecks,
 		ScanRemovedPackages: opt.ScanRemovedPkgs,
+		ListAllPackages:     opt.ListAllPkgs,
 	}
 	log.Logger.Debugf("Vulnerability type:  %s", scanOptions.VulnType)
 
-	results, err := s.ScanArtifact(ctx, scanOptions)
+	report, err := s.ScanArtifact(ctx, scanOptions)
 	if err != nil {
 		return xerrors.Errorf("error in image scan: %w", err)
 	}
 
 	resultClient := initializeResultClient()
+	results := report.Results
 	for i := range results {
-		vulns, err := resultClient.Filter(ctx, results[i].Vulnerabilities,
-			opt.Severities, opt.IgnoreUnfixed, opt.IgnoreFile, opt.IgnorePolicy)
+		vulns, misconfSummary, misconfs, err := resultClient.Filter(ctx, results[i].Vulnerabilities, results[i].Misconfigurations,
+			opt.Severities, opt.IgnoreUnfixed, opt.IncludeNonFailures, opt.IgnoreFile, opt.IgnorePolicy)
 		if err != nil {
 			return xerrors.Errorf("filter error: %w", err)
 		}
 		results[i].Vulnerabilities = vulns
+		results[i].Misconfigurations = misconfs
+		results[i].MisconfSummary = misconfSummary
 	}
 
-	if err = report.WriteResults(opt.Format, opt.Output, opt.Severities, results, opt.Template, false); err != nil {
+	if err = pkgReport.Write(report, pkgReport.Option{
+		Format:             opt.Format,
+		Output:             opt.Output,
+		Severities:         opt.Severities,
+		OutputTemplate:     opt.Template,
+		Light:              false,
+		IncludeNonFailures: opt.IncludeNonFailures,
+		Trace:              opt.Trace,
+	}); err != nil {
 		return xerrors.Errorf("unable to write results: %w", err)
 	}
 
@@ -109,10 +124,22 @@ func initializeScanner(ctx context.Context, opt Option) (scanner.Scanner, func()
 		disabledAnalyzers = []analyzer.Type{}
 	}
 
-	// TODO: fix the scanner option and enable config analyzers once we finalize the specification of config scanning.
-	configScannerOptions := config.ScannerOption{}
-	disabledAnalyzers = append(disabledAnalyzers, analyzer.TypeYaml, analyzer.TypeTOML, analyzer.TypeJSON,
-		analyzer.TypeDockerfile, analyzer.TypeHCL)
+	// ScannerOptions is filled only when config scanning is enabled.
+	var configScannerOptions config.ScannerOption
+	if utils.StringInSlice(types.SecurityCheckConfig, opt.SecurityChecks) {
+		builtinPolicyPaths, err := operation.InitBuiltinPolicies(ctx, false)
+		if err != nil {
+			return scanner.Scanner{}, nil, xerrors.Errorf("failed to initialize default policies: %w", err)
+		}
+
+		configScannerOptions = config.ScannerOption{
+			Trace:        opt.Trace,
+			Namespaces:   append(opt.PolicyNamespaces, defaultPolicyNamespace),
+			PolicyPaths:  append(opt.PolicyPaths, builtinPolicyPaths...),
+			DataPaths:    opt.DataPaths,
+			FilePatterns: opt.FilePatterns,
+		}
+	}
 
 	if opt.Input != "" {
 		// Scan tar file
@@ -134,7 +161,7 @@ func initializeScanner(ctx context.Context, opt Option) (scanner.Scanner, func()
 	return s, cleanup, nil
 }
 
-func exit(c Option, results report.Results) {
+func exit(c Option, results pkgReport.Results) {
 	if c.ExitCode != 0 {
 		for _, result := range results {
 			if len(result.Vulnerabilities) > 0 {
