@@ -8,11 +8,11 @@ import (
 	"golang.org/x/xerrors"
 
 	"github.com/aquasecurity/fanal/cache"
+	"github.com/aquasecurity/trivy/pkg/result"
 	"github.com/aquasecurity/trivy/pkg/rpc"
 	"github.com/aquasecurity/trivy/pkg/scanner"
 	"github.com/aquasecurity/trivy/pkg/scanner/local"
 	"github.com/aquasecurity/trivy/pkg/types"
-	"github.com/aquasecurity/trivy/pkg/vulnerability"
 	rpcCache "github.com/aquasecurity/trivy/rpc/cache"
 	rpcScanner "github.com/aquasecurity/trivy/rpc/scanner"
 )
@@ -21,26 +21,27 @@ import (
 var ScanSuperSet = wire.NewSet(
 	local.SuperSet,
 	wire.Bind(new(scanner.Driver), new(local.Scanner)),
-	vulnerability.SuperSet,
+	result.SuperSet,
 	NewScanServer,
 )
 
 // ScanServer implements the scanner
 type ScanServer struct {
 	localScanner scanner.Driver
-	resultClient vulnerability.Client
+	resultClient result.Client
 }
 
 // NewScanServer is the factory method for scanner
-func NewScanServer(s scanner.Driver, vulnClient vulnerability.Client) *ScanServer {
+func NewScanServer(s scanner.Driver, vulnClient result.Client) *ScanServer {
 	return &ScanServer{localScanner: s, resultClient: vulnClient}
 }
 
 // Scan scans and return response
 func (s *ScanServer) Scan(_ context.Context, in *rpcScanner.ScanRequest) (*rpcScanner.ScanResponse, error) {
 	options := types.ScanOptions{
-		VulnType:       in.Options.VulnType,
-		SecurityChecks: in.Options.SecurityChecks,
+		VulnType:        in.Options.VulnType,
+		SecurityChecks:  in.Options.SecurityChecks,
+		ListAllPackages: in.Options.ListAllPackages,
 	}
 	results, os, eosl, err := s.localScanner.Scan(in.Target, in.ArtifactId, in.BlobIds, options)
 	if err != nil {
@@ -48,7 +49,7 @@ func (s *ScanServer) Scan(_ context.Context, in *rpcScanner.ScanRequest) (*rpcSc
 	}
 
 	for i := range results {
-		s.resultClient.FillInfo(results[i].Vulnerabilities, results[i].Type)
+		s.resultClient.FillVulnerabilityInfo(results[i].Vulnerabilities, results[i].Type)
 	}
 	return rpc.ConvertToRPCScanResponse(results, os, eosl), nil
 }
