@@ -13,30 +13,10 @@ import (
 	"golang.org/x/xerrors"
 
 	"github.com/aquasecurity/fanal/analyzer"
-	_ "github.com/aquasecurity/fanal/analyzer/command/apk"
-	_ "github.com/aquasecurity/fanal/analyzer/library/bundler"
-	_ "github.com/aquasecurity/fanal/analyzer/library/cargo"
-	_ "github.com/aquasecurity/fanal/analyzer/library/composer"
-	_ "github.com/aquasecurity/fanal/analyzer/library/gobinary"
-	_ "github.com/aquasecurity/fanal/analyzer/library/gomod"
-	_ "github.com/aquasecurity/fanal/analyzer/library/jar"
-	_ "github.com/aquasecurity/fanal/analyzer/library/npm"
-	_ "github.com/aquasecurity/fanal/analyzer/library/nuget"
-	_ "github.com/aquasecurity/fanal/analyzer/library/pipenv"
-	_ "github.com/aquasecurity/fanal/analyzer/library/poetry"
-	_ "github.com/aquasecurity/fanal/analyzer/library/yarn"
-	_ "github.com/aquasecurity/fanal/analyzer/os/alpine"
-	_ "github.com/aquasecurity/fanal/analyzer/os/amazonlinux"
-	_ "github.com/aquasecurity/fanal/analyzer/os/debian"
-	_ "github.com/aquasecurity/fanal/analyzer/os/photon"
-	_ "github.com/aquasecurity/fanal/analyzer/os/redhatbase"
-	_ "github.com/aquasecurity/fanal/analyzer/os/suse"
-	_ "github.com/aquasecurity/fanal/analyzer/os/ubuntu"
-	_ "github.com/aquasecurity/fanal/analyzer/pkg/apk"
-	_ "github.com/aquasecurity/fanal/analyzer/pkg/dpkg"
-	_ "github.com/aquasecurity/fanal/analyzer/pkg/rpm"
+	_ "github.com/aquasecurity/fanal/analyzer/all"
 	"github.com/aquasecurity/fanal/applier"
 	ftypes "github.com/aquasecurity/fanal/types"
+	dbTypes "github.com/aquasecurity/trivy-db/pkg/types"
 	"github.com/aquasecurity/trivy/pkg/detector/library"
 	ospkgDetector "github.com/aquasecurity/trivy/pkg/detector/ospkg"
 	"github.com/aquasecurity/trivy/pkg/log"
@@ -81,7 +61,7 @@ func (s Scanner) Scan(target, versionedArtifactID string, versionedBlobIDs []str
 	artifactDetail, err := s.applier.ApplyLayers(versionedArtifactID, versionedBlobIDs)
 	switch {
 	case errors.Is(err, analyzer.ErrUnknownOS):
-		log.Logger.Warn("OS is not detected and vulnerabilities in OS packages are not detected.")
+		log.Logger.Debug("OS is not detected and vulnerabilities in OS packages are not detected.")
 	case errors.Is(err, analyzer.ErrNoPkgsDetected):
 		log.Logger.Warn("No OS package is detected. Make sure you haven't deleted any files that contain information about the installed packages.")
 		log.Logger.Warn(`e.g. files under "/lib/apk/db/", "/var/lib/dpkg/" and "/var/lib/rpm"`)
@@ -92,29 +72,59 @@ func (s Scanner) Scan(target, versionedArtifactID string, versionedBlobIDs []str
 	var eosl bool
 	var results report.Results
 
-	if utils.StringInSlice("os", options.VulnType) && artifactDetail.OS != nil {
-		var result *report.Result
-		result, eosl, err = s.scanOSPkgs(target, artifactDetail, options)
+	// Scan OS packages and programming language dependencies
+	if utils.StringInSlice(types.SecurityCheckVulnerability, options.SecurityChecks) {
+		var vulnResults report.Results
+		vulnResults, eosl, err = s.checkVulnerabilities(target, artifactDetail, options)
 		if err != nil {
-			return nil, nil, false, xerrors.Errorf("unable to scan OS packages: %w", err)
-		} else if result != nil {
-			results = append(results, *result)
+			return nil, nil, false, xerrors.Errorf("failed to detect vulnerabilities: %w", err)
 		}
+		results = append(results, vulnResults...)
 	}
 
-	if utils.StringInSlice("library", options.VulnType) {
-		libResults, err := s.scanLibrary(artifactDetail.Applications, options)
-		if err != nil {
-			return nil, nil, false, xerrors.Errorf("failed to scan application libraries: %w", err)
-		}
-		results = append(results, libResults...)
+	// Scan IaC config files
+	if utils.StringInSlice(types.SecurityCheckConfig, options.SecurityChecks) {
+		configResults := s.misconfsToResults(artifactDetail.Misconfigurations, options)
+		results = append(results, configResults...)
 	}
 
 	return results, artifactDetail.OS, eosl, nil
 }
 
+func (s Scanner) checkVulnerabilities(target string, detail ftypes.ArtifactDetail, options types.ScanOptions) (
+	report.Results, bool, error) {
+	var eosl bool
+	var results report.Results
+
+	if utils.StringInSlice(types.VulnTypeOS, options.VulnType) {
+		result, detectedEosl, err := s.scanOSPkgs(target, detail, options)
+		if err != nil {
+			return nil, false, xerrors.Errorf("unable to scan OS packages: %w", err)
+		} else if result != nil {
+			results = append(results, *result)
+		}
+		eosl = detectedEosl
+	}
+
+	if utils.StringInSlice(types.VulnTypeLibrary, options.VulnType) {
+		libResults, err := s.scanLibrary(detail.Applications, options)
+		if err != nil {
+			return nil, false, xerrors.Errorf("failed to scan application libraries: %w", err)
+		}
+		results = append(results, libResults...)
+	}
+
+	return results, eosl, nil
+}
+
 func (s Scanner) scanOSPkgs(target string, detail ftypes.ArtifactDetail, options types.ScanOptions) (
 	*report.Result, bool, error) {
+	if detail.OS == nil {
+		log.Logger.Debug("Detected OS: unknown")
+		return nil, false, nil
+	}
+	log.Logger.Infof("Detected OS: %s", detail.OS.Family)
+
 	pkgs := detail.Packages
 	if options.ScanRemovedPackages {
 		pkgs = mergePkgs(pkgs, detail.HistoryPackages)
@@ -152,14 +162,15 @@ func (s Scanner) detectVulnsInOSPkgs(target, osFamily, osName string, pkgs []fty
 	result := &report.Result{
 		Target:          artifactDetail,
 		Vulnerabilities: vulns,
+		Class:           report.ClassOSPkg,
 		Type:            osFamily,
 	}
 	return result, eosl, nil
 }
 
 func (s Scanner) scanLibrary(apps []ftypes.Application, options types.ScanOptions) (report.Results, error) {
+	log.Logger.Infof("Number of language-specific files: %d", len(apps))
 	if len(apps) == 0 {
-		log.Logger.Info("Trivy skips scanning programming language libraries because no supported file was detected")
 		return nil, nil
 	}
 
@@ -188,6 +199,7 @@ func (s Scanner) scanLibrary(apps []ftypes.Application, options types.ScanOption
 		libReport := report.Result{
 			Target:          app.FilePath,
 			Vulnerabilities: vulns,
+			Class:           report.ClassLangPkg,
 			Type:            app.Type,
 		}
 		if options.ListAllPackages {
@@ -212,7 +224,95 @@ func (s Scanner) scanLibrary(apps []ftypes.Application, options types.ScanOption
 	return results, nil
 }
 
+func (s Scanner) misconfsToResults(misconfs []ftypes.Misconfiguration, options types.ScanOptions) report.Results {
+	log.Logger.Infof("Detected config files: %d", len(misconfs))
+	var results report.Results
+	for _, misconf := range misconfs {
+		if skipped(misconf.FilePath, options.SkipFiles, options.SkipDirs) {
+			continue
+		}
+
+		log.Logger.Debugf("Scanned config file: %s", misconf.FilePath)
+
+		var detected []types.DetectedMisconfiguration
+
+		for _, f := range misconf.Failures {
+			detected = append(detected, toDetectedMisconfiguration(f, dbTypes.SeverityCritical, types.StatusFailure, misconf.Layer))
+		}
+		for _, w := range misconf.Warnings {
+			detected = append(detected, toDetectedMisconfiguration(w, dbTypes.SeverityMedium, types.StatusFailure, misconf.Layer))
+		}
+		for _, w := range misconf.Successes {
+			detected = append(detected, toDetectedMisconfiguration(w, dbTypes.SeverityUnknown, types.StatusPassed, misconf.Layer))
+		}
+		for _, w := range misconf.Exceptions {
+			detected = append(detected, toDetectedMisconfiguration(w, dbTypes.SeverityUnknown, types.StatusException, misconf.Layer))
+		}
+
+		results = append(results, report.Result{
+			Target:            misconf.FilePath,
+			Class:             report.ClassConfig,
+			Type:              misconf.FileType,
+			Misconfigurations: detected,
+		})
+	}
+
+	sort.Slice(results, func(i, j int) bool {
+		return results[i].Target < results[j].Target
+	})
+
+	return results
+}
+
+func toDetectedMisconfiguration(res ftypes.MisconfResult, defaultSeverity dbTypes.Severity,
+	status types.MisconfStatus, layer ftypes.Layer) types.DetectedMisconfiguration {
+
+	severity := defaultSeverity
+	sev, err := dbTypes.NewSeverity(res.Severity)
+	if err != nil {
+		log.Logger.Warnf("severity must be %s, but %s", dbTypes.SeverityNames, res.Severity)
+	} else {
+		severity = sev
+	}
+
+	msg := strings.TrimSpace(res.Message)
+	if msg == "" {
+		msg = "No issues found"
+	}
+
+	var primaryURL string
+	if strings.HasPrefix(res.Namespace, "appshield.") {
+		primaryURL = fmt.Sprintf("https://avd.aquasec.com/appshield/%s", strings.ToLower(res.ID))
+		res.References = append(res.References, primaryURL)
+	} else if strings.Contains(res.Type, "tfsec") {
+		for _, ref := range res.References {
+			if strings.HasPrefix(ref, "https://tfsec.dev/docs/") {
+				primaryURL = ref
+				break
+			}
+		}
+	}
+
+	return types.DetectedMisconfiguration{
+		ID:          res.ID,
+		Type:        res.Type,
+		Title:       res.Title,
+		Description: res.Description,
+		Message:     msg,
+		Resolution:  res.RecommendedActions,
+		Namespace:   res.Namespace,
+		Query:       res.Query,
+		Severity:    severity.String(),
+		PrimaryURL:  primaryURL,
+		References:  res.References,
+		Status:      status,
+		Layer:       layer,
+		Traces:      res.Traces,
+	}
+}
+
 func skipped(filePath string, skipFiles, skipDirs []string) bool {
+	filePath = strings.TrimLeft(filepath.Clean(filePath), string(os.PathSeparator))
 	for _, skipFile := range skipFiles {
 		skipFile = strings.TrimLeft(filepath.Clean(skipFile), string(os.PathSeparator))
 		if filePath == skipFile {
