@@ -23,11 +23,14 @@ const (
 
 	// SecurityCheckVulnerability is a security check of vulnerabilities
 	SecurityCheckVulnerability = SecurityCheck("vuln")
+
+	// SecurityCheckConfig is a security check of misconfigurations
+	SecurityCheckConfig = SecurityCheck("config")
 )
 
 var (
 	vulnTypes      = []string{VulnTypeOS, VulnTypeLibrary}
-	securityChecks = []string{SecurityCheckVulnerability}
+	securityChecks = []string{SecurityCheckVulnerability, SecurityCheckConfig}
 )
 
 // NewVulnType returns an instance of VulnType
